=============
Release Notes
=============

-----
0.5.0
-----

Released: unreleased

.. rubric:: Features

*  Completely refactored to be in the package ``lockss.debugpanel``.

*  Using Poetry to make uploadable to and installable from PyPI as `lockss-debugpanel <https://pypi.org/project/lockss-debugpanel>`_.

*  Added the ``verify-files`` command.
